@@ -1,9 +1,10 @@
-package Ryu 0.002;
-$Ryu::VERSION = '0.002';
+package Ryu;
 # ABSTRACT: stream and data flow handling for async code
 use strict;
 use warnings;
 
+our $VERSION = '0.003';
+
 =encoding utf8
 
 =head1 NAME
@@ -12,7 +13,7 @@ Ryu - asynchronous stream building blocks
 
 =head1 SYNOPSIS
 
- #!/usr/bin/env perl 
+ #!/usr/bin/env perl
  use strict;
  use warnings;
  
