@@ -1,5 +1,5 @@
 package Ryu::Observable;
-$Ryu::Observable::VERSION = '0.002';
+$Ryu::Observable::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -51,7 +51,13 @@ sub subscribe { my $self = shift; push @{$self->{subscriptions}}, @_; $self }
 
 =cut
 
-sub notify_all { my $self = shift; $_->($self->{value}) for @{$self->{subscriptions}}; $self }
+sub notify_all {
+	my $self = shift;
+	for my $sub (@{$self->{subscriptions}}) {
+		$sub->($_) for $self->{value}
+	}
+	$self
+}
 
 =head2 set
 
